Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RandContainerName ¶
func RandContainerName() string
RandContainerName generate a random name for a docker container base on a timestamp
Types ¶
type Container ¶
type Container struct {
StepId string
container.ContainerCreateCreatedBody
context.Context
Name string
// contains filtered or unexported fields
}
func NewContainer ¶
func NewContainer(config *DockerImageConfig, stepId string) (*Container, error)
NewContainer create a new container instance from a configuration
type DockerImageConfig ¶
Click to show internal directories.
Click to hide internal directories.